==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/pl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pulpit",
    "Dashboard app" : "Aplikacja Pulpit",
    "Show something" : "Pokaż coś",
    "Customize" : "Dostosuj",
    "Edit widgets" : "Edytuj widżety",
    "Get more widgets from the app store" : "Pobierz więcej widżetów ze sklepu z aplikacjami",
    "Change background image" : "Zmień obraz tła",
    "Weather service" : "Serwis pogodowy",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ze względu na Twoją prywatność dane pogodowe są pobierane przez serwer Nextcloud w Twoim imieniu. Usługa pogodowa nie otrzymuje żadnych danych osobowych.",
    "Weather data from Met.no" : "Dane pogodowe z Met.no",
    "geocoding with Nominatim" : "geokodowanie z Nominatim",
    "elevation data from OpenTopoData" : "dane wysokościowe z OpenTopoData",
    "Weather" : "Pogoda",
    "Status" : "Status",
    "Good evening, {name}" : "Dobry wieczór, {name}",
    "Good evening" : "Dobry wieczór",
    "Good afternoon, {name}" : "Dzień dobry, {name}",
    "Good afternoon" : "Dzień dobry",
    "Good morning, {name}" : "Dzień dobry, {name}",
    "Good morning" : "Dzień dobry",
    "Good night, {name}" : "Dobranoc, {name}",
    "Good night" : "Dobranoc",
    "Pick from files" : "Wybierz z plików",
    "Default images" : "Obrazy domyślne",
    "Plain background" : "Zwykłe tło",
    "Insert from {productName}" : "Wstaw z {productName}"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/pl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pulpit",
    "Dashboard app" : "Aplikacja Pulpit",
    "Show something" : "Pokaż coś",
    "Customize" : "Dostosuj",
    "Edit widgets" : "Edytuj widżety",
    "Get more widgets from the app store" : "Pobierz więcej widżetów ze sklepu z aplikacjami",
    "Change background image" : "Zmień obraz tła",
    "Weather service" : "Serwis pogodowy",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Ze względu na Twoją prywatność dane pogodowe są pobierane przez serwer Nextcloud w Twoim imieniu. Usługa pogodowa nie otrzymuje żadnych danych osobowych.",
    "Weather data from Met.no" : "Dane pogodowe z Met.no",
    "geocoding with Nominatim" : "geokodowanie z Nominatim",
    "elevation data from OpenTopoData" : "dane wysokościowe z OpenTopoData",
    "Weather" : "Pogoda",
    "Status" : "Status",
    "Good evening, {name}" : "Dobry wieczór, {name}",
    "Good evening" : "Dobry wieczór",
    "Good afternoon, {name}" : "Dzień dobry, {name}",
    "Good afternoon" : "Dzień dobry",
    "Good morning, {name}" : "Dzień dobry, {name}",
    "Good morning" : "Dzień dobry",
    "Good night, {name}" : "Dobranoc, {name}",
    "Good night" : "Dobranoc",
    "Pick from files" : "Wybierz z Plików",
    "Default images" : "Obrazy domyślne",
    "Plain background" : "Zwykłe tło",
    "Insert from {productName}" : "Wstaw z {productName}"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
